@@ -41,24 +41,53 @@ places_bookmarks_init()
     DBG("initializing model");
 
     Bookmarks *b = g_new0(Bookmarks, 1);
-
+    
     b->system = places_bookmarks_system_init();
-    b->volumes = places_bookmarks_volumes_init();
-    b->user = places_bookmarks_user_init(b->system); // user depends on system for 
-                                                     // places_bookmarks_system_bi_system_mod().
-                                                     // It's a sucky aspect of this design...
-
     return b;
 }
 
+void
+places_bookmarks_enable(Bookmarks *b, gint enable_mask)
+{
+    gboolean enable_volumes, enable_user;
+    
+    // Enable/disable volumes
+    enable_volumes = (enable_mask & PLACES_BOOKMARKS_ENABLE_VOLUMES);
+
+    if(b->volumes == NULL && enable_volumes){
+        b->volumes = places_bookmarks_volumes_init();
+    }else if(b->volumes != NULL && !enable_volumes) {
+        places_bookmarks_volumes_finalize(b->volumes);
+        b->volumes = NULL;
+    }
+
+    // Enable/disable GTK bookmarks
+    enable_user = (enable_mask & PLACES_BOOKMARKS_ENABLE_USER);
+
+    if(b->user == NULL && enable_user){
+        b->user = places_bookmarks_user_init(b->system); // user depends on system for 
+                                                         // places_bookmarks_system_bi_system_mod().
+                                                         // It's a sucky aspect of this design...
+    }else if(b->user != NULL && !enable_user){
+        places_bookmarks_user_finalize(b->user);
+        b->user = NULL;
+    }
+
+}
+
 void
 places_bookmarks_visit(Bookmarks *b,
                        BookmarksVisitor *visitor)
 {
     places_bookmarks_system_visit  (b->system,  visitor);
-    places_bookmarks_volumes_visit (b->volumes, visitor);
-    visitor->separator             (visitor->pass_thru);
-    places_bookmarks_user_visit    (b->user,    visitor);
+
+    if(b->volumes != NULL)
+        places_bookmarks_volumes_visit (b->volumes, visitor);
+
+    if(b->user != NULL){
+        visitor->separator             (visitor->pass_thru);
+        places_bookmarks_user_visit    (b->user,    visitor);
+    }
 }
 
 gboolean
@@ -66,9 +95,15 @@ places_bookmarks_changed(Bookmarks *b)
 {
     // try to avoid short-circuit of || since changed() has side-effects
     gboolean changed = FALSE;
-    changed = places_bookmarks_system_changed(b->system)    || changed;
-    changed = places_bookmarks_volumes_changed(b->volumes)  || changed;
-    changed = places_bookmarks_user_changed(b->user)        || changed;
+
+    changed = places_bookmarks_system_changed(b->system)        || changed;
+
+    if(b->volumes != NULL)
+        changed = places_bookmarks_volumes_changed(b->volumes)  || changed;
+
+    if(b->user != NULL)
+        changed = places_bookmarks_user_changed(b->user)        || changed;
+
     return changed;
 }
 
@@ -78,11 +113,7 @@ places_bookmarks_finalize(Bookmarks *b)
     places_bookmarks_system_finalize(b->system);
     b->system = NULL;
     
-    places_bookmarks_volumes_finalize(b->volumes);
-    b->volumes = NULL;
-    
-    places_bookmarks_user_finalize(b->user);
-    b->user = NULL;
+    places_bookmarks_enable(b, PLACES_BOOKMARKS_ENABLE_NONE);
 
     g_free(b);
 }
