@@ -23,24 +23,33 @@
 #include <gtk/gtk.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
 
+typedef struct _PlacesData PlacesData;
+#include "cfg.h"
+
 #define PLUGIN_NAME "places"
 
-typedef struct
+struct _PlacesData
 {
   // plugin
   XfcePanelPlugin   *plugin;
 
+  // configuration
+  PlacesConfig      *cfg;
+
   // view
   GtkWidget         *view_button;
+  GtkWidget         *view_button_box;
   GtkWidget         *view_button_image;
+  GtkWidget         *view_button_label;
   GtkWidget         *view_menu;
   GtkTooltips       *view_tooltips;
   gulong             view_theme_timeout_id;
+  gboolean           view_just_separated;
 
   // model
   gpointer           bookmarks;
 
-} PlacesData;
+};
 
 void places_load_thunar(const gchar*);
 
